;NSIS Modern User Interface
;Basic Example Script written by Joost Verburg
;Adapted for LcdBible by Lynn Allan

!define LCD_TEST_VERSION
; !define LCD_RELEASE_VERSION

!define PROJECT_FAMILY "CrossWire"
!define PROJECT_NAME "LcdBible"
!define LCD_REGKEY "SOFTWARE\${PROJECT_FAMILY}\${PROJECT_NAME}"
!define LCD_PRODUCT_VERSION 1.3.0.11
!define LCD_FILE_VERSION 1.30K
!define LCD_COMPANY "CrossWire Bible Society"
!define LCD_URL http://lcdbible.sourceforge.net
!define LCD_DATE_DISPLAY 2005-Oct-17

!define UNINSTALL_SUBHIVE "SOFTWARE\Microsoft\Windows\CurrentVersion\Uninstall\${PROJECT_FAMILY}_${PROJECT_NAME}"
;--------------------------------
; !include WriteEnvStr.nsh
;Include Modern UI
  !include "MUI.nsh"
;--------------------------------
;General

  ;Name and file
  Name "${PROJECT_NAME}"
  OutFile "LcdBibleStarterKitSetup.exe"

  ;Default installation folder
  InstallDir "$PROGRAMFILES\${PROJECT_FAMILY}\${PROJECT_NAME}"
  
  ;Get installation folder from registry if available
  InstallDirRegKey HKLM "UNINSTALL_SUBHIVE" "InstallLocation"

# Variables
Var StartMenuGroup
Var TestMenuGroupExists
Var SwordPathFolder
var MyFlagSwordPathChanged
var ViewFullTutorialFlag

# MUI defines
!define MUI_ICON "orange-install.ico"
!define MUI_FINISHPAGE_NOAUTOCLOSE
!define MUI_STARTMENUPAGE_REGISTRY_ROOT HKCU
!define MUI_STARTMENUPAGE_NODISABLE
!define MUI_STARTMENUPAGE_REGISTRY_KEY "SOFTWARE\${PROJECT_FAMILY}\${PROJECT_NAME}"
; !define MUI_STARTMENUPAGE_REGISTRY_VALUENAME $StartMenuGroup
!define MUI_STARTMENUPAGE_DEFAULT_FOLDER "${PROJECT_FAMILY}_${PROJECT_NAME}"
!define MUI_STARTMENUPAGE_REGISTRY_VALUENAME StartMenuGroup

!define MUI_UNICON "orange-install.ico"
!define MUI_UNFINISHPAGE_NOAUTOCLOSE

;--------------------------------
;Interface Settings

!ifdef LCD_RELEASE_VERSION
  !define MUI_ABORTWARNING
!endif  

;--------------------------------
;Pages

!ifdef LCD_RELEASE_VERSION
  !insertmacro MUI_PAGE_LICENSE ..\stage\LCDBIBLE_LICENSE
!endif  
  !insertmacro MUI_PAGE_COMPONENTS

!ifdef LCD_RELEASE_VERSION
  !define MUI_PAGE_HEADER_TEXT "MainText: Set directory to install application"
  !define MUI_PAGE_HEADER_SUBTEXT "SubText: Set directory to install application"
  !define MUI_DIRECTORYPAGE_TEXT_TOP "First Directory Page"
  !insertmacro MUI_PAGE_DIRECTORY
!endif  

!ifdef LCD_RELEASE_VERSION
  !define MUI_PAGE_HEADER_TEXT "MainText: Set directory to install resources based on SWORD_PATH"
  !define MUI_PAGE_HEADER_SUBTEXT "SubText: Set directory to install resources based on SWORD_PATH (stubbed for now)"
  !define MUI_DIRECTORYPAGE_VARIABLE $SwordPathFolder
  !define MUI_DIRECTORYPAGE_TEXT_TOP "Second Directory Page (stubbed for now)"
  !insertmacro MUI_PAGE_DIRECTORY
!endif  

  !insertmacro MUI_PAGE_STARTMENU Application $StartMenuGroup
  !insertmacro MUI_PAGE_INSTFILES
  
  !insertmacro MUI_UNPAGE_CONFIRM
  !insertmacro MUI_UNPAGE_INSTFILES
  
;--------------------------------
;Languages
 
  !insertmacro MUI_LANGUAGE "English"

CRCCheck on
XPStyle on
ShowInstDetails show
BGGradient 000080 000000 FFFFFF
VIProductVersion ${LCD_PRODUCT_VERSION}
VIAddVersionKey /LANG=${LANG_ENGLISH} ProductName "${PROJECT_NAME}"
VIAddVersionKey /LANG=${LANG_ENGLISH} CompanyName "${LCD_COMPANY}"
VIAddVersionKey /LANG=${LANG_ENGLISH} CompanyWebsite "${LCD_URL}"
VIAddVersionKey /LANG=${LANG_ENGLISH} FileDescription "Installer for ${PROJECT_NAME}"
VIAddVersionKey /LANG=${LANG_ENGLISH} FileVersion "${LCD_FILE_VERSION}"
VIAddVersionKey /LANG=${LANG_ENGLISH} LegalCopyright ""
VIAddVersionKey /LANG=${LANG_ENGLISH} ProductVersion "${LCD_PRODUCT_VERSION}"
ShowUninstDetails show

;--------------------------------
;Installer Sections
SectionGroup "Software Installation" SgInstallation
Section "!Install Application" SecInstallApp

  SectionIn RO
  SetOutPath "$INSTDIR"
  
  SetOverwrite on
  File /oname=LcdBible.exe ..\stage\LcdBible.exe
  File /oname=InstallManager.exe ..\stage\TestInstallManager.exe
!ifdef LCD_RELEASE_VERSION
  CreateDirectory $INSTDIR\mods.d
  CreateDirectory $INSTDIR\modules
  SetOutPath $INSTDIR\mods.d
  File /r ..\stage\mods.d\*
  SetOutPath $INSTDIR\modules
  File /r ..\stage\modules\*
!endif  
  SetOutPath $INSTDIR
  File ..\stage\layout.conf
  File ..\stage\LcdTutorial.rtf
  File ..\stage\Lcd_changelog.htm
  File ..\stage\options.conf
  File ..\stage\readme.txt
  WriteRegStr HKCU "${LCD_REGKEY}\Components" "${PROJECT_NAME}Installed" 1
  WriteRegStr HKCU "${LCD_REGKEY}\Components" "${PROJECT_NAME}Version" "${LCD_FILE_VERSION}"

  WriteRegDWORD HKCU ${LCD_REGKEY}\Settings "DlgBottom"           550
  WriteRegDWORD HKCU ${LCD_REGKEY}\Settings "DlgLeft"             5
  WriteRegDWORD HKCU ${LCD_REGKEY}\Settings "DlgRight"            750
  WriteRegDWORD HKCU ${LCD_REGKEY}\Settings "DlgTop"              5

  ;Store installation folder
  WriteRegStr HKCU "Software\${PROJECT_FAMILY}\${PROJECT_NAME}" "" $INSTDIR
SectionEnd

Section /o "Same directory as The SWORD Project" SecSwordProject
  MessageBox MB_OK "Logic here to install ${PROJECT_NAME} in same directory as 'The SWORD Project'"
SectionEnd

Section /o "Set SWORD_PATH" SecSwordPath
  MessageBox MB_OK "Logic here to install ${PROJECT_NAME} in directory indicated by environment variable SWORD_PATH"
SectionEnd

Section "Create Desktop icon" SecDesktopIcon
  MessageBox MB_OK "Desktop icon creation stubbed"
SectionEnd

SectionGroupEnd

SectionGroup "Resources" SgResources 
Section "ISV Resource" SecIsvResource
SectionEnd

Section /o "KJV Resource" SecKjvResource
  MessageBox MB_OK "KJV resource installed stubbed to keep StarterKit smaller"
SectionEnd

Section /o "WEB Resource" SecWebResource
  MessageBox MB_OK "WEB resource installed stubbed to keep StarterKit smaller"
SectionEnd

Section /o "Bible Texts" SecBibleTexts
  ExecShell "open" "http://www.crosswire.org/sword/modules/ModDisp.jsp?modType=Bibles"
SectionEnd

Section "Show readme.txt" SecReadme
  ExecWait "NotePad $INSTDIR\readme.txt"
SectionEnd

SectionGroupEnd

SectionGroup "Run" SgRun
Section /o "Run InstallManager" SecInstallManager
  ExecWait "$INSTDIR\InstallManager.exe"
SectionEnd

Section /o "Run Application" SecRunApplication
  ExecWait "$INSTDIR\LcdBible.exe"
SectionEnd
SectionGroupEnd

SectionGroup "Documentation" SgDocumentation
Section /o "View Mini-Tutorial" SecDocMiniTutorial
  MessageBox MB_OK "${PROJECT_FAMILY}: ${PROJECT_NAME} ver ${LCD_FILE_VERSION} (${LCD_DATE_DISPLAY}) \
  $\r$\nMini Tutorial for new users: \
  $\r$\n1. Type 'acts 17.11' and press the Enter Key or Ctrl^R. \
  $\r$\n2. Type 'scriptures' and press the Enter Key or Ctrl^F. \
  $\r$\n3. 'Hover' the mouse cursor over the 'luke 24:27' reference on the left. \
  $\r$\n4. Click on the 'Romans 15:4' reference to see the verse and context.\
  $\r$\n5. Click on the '?-Mark' in the upper right and then click on a control \
  $\r$\n       (such as the 'Find' button) to learn what that button does. \
  $\r$\n \
  $\r$\nThat's 90% of what you need to know to use basic features of ${PROJECT_NAME}. \
  $\r$\n \
  $\r$\nThere is a full tutorial oriented to non-techies that can be viewed \
  $\r$\nby selecting 'Start' + 'Programs' + '${PROJECT_NAME} Folder' + 'Tutorial' \
  $\r$\nIt may be easier to print that tutorial to follow along. \
  $\r$\n \
  $\r$\nFeedback appreciated: ${PROJECT_NAME}_at_yahoogroups.com \
  $\r$\nSWORD_PATH can be set. Currently = $SwordPathFolder \
  $\r$\n \
  $\r$\nEnjoy! ${PROJECT_NAME} is 'freeware' (no charge)"
SectionEnd

Section /o "View Full Tutorial" SecDocFullTutorial
  StrCpy $ViewFullTutorialFlag "yes"
;  MessageBox MB_OK "Reached View Full Tutorial"
  ExecShell "open" "$INSTDIR\LcdTutorial.rtf"
SectionEnd

Section /o "Change-Log" SecDocChangeLog
  ExecShell "open" "$INSTDIR\Lcd_changelog.htm"
SectionEnd

Section /o "CrossWire Home" SecDocCrosswireHome
  ExecShell "open" "http://www.crosswire.org"
SectionEnd

Section /o "Slideshow" SecDocSlideshow
  ExecShell "open" "http://www.viewletcentral.com/vc/viewlet.html?id=82532565"
SectionEnd

Section /o "LcdBible Home" SecDocLcdBibleHome
  ExecShell "open" "http://lcdbible.sourceforge.net"
SectionEnd
SectionGroupEnd

Section -post SEC0001
  WriteRegStr HKCU "${LCD_REGKEY}" InstallLocation $INSTDIR
  WriteRegStr HKCU "${LCD_REGKEY}" StartMenuGroup $StartMenuGroup
  WriteUninstaller $INSTDIR\uninstall.exe
  !insertmacro MUI_STARTMENU_WRITE_BEGIN Application
;  MessageBox MB_OK "Within -post SEC00001 $\r$\n \
;                   SMPROGRAMS: $SMPROGRAMS  $\r$\n \
;                   StartMenuGroup: $StartMenuGroup $\r$\n \
;                   ProjectName: ${PROJECT_NAME} $\r$\n \
;                   InstallDirectory: $INSTDIR $\r$\n \
;                   UninstallSubhive: ${UNINSTALL_SUBHIVE}"
; 
  SetOutPath $SMPROGRAMS\$StartMenuGroup
  CreateShortCut "$SMPROGRAMS\$StartMenuGroup\${PROJECT_NAME}.lnk" $INSTDIR\${PROJECT_NAME}.exe
  CreateShortCut "$SMPROGRAMS\$StartMenuGroup\InstallManager.lnk" $INSTDIR\InstallManager.exe
  CreateShortCut "$SMPROGRAMS\$StartMenuGroup\Uninstall ${PROJECT_NAME}.lnk" $INSTDIR\uninstall.exe
  !insertmacro MUI_STARTMENU_WRITE_END
  WriteRegStr HKLM "${UNINSTALL_SUBHIVE}" DisplayIcon $INSTDIR\uninstall.exe
  WriteRegStr HKLM "${UNINSTALL_SUBHIVE}" DisplayName "${PROJECT_NAME}"
  WriteRegStr HKLM "${UNINSTALL_SUBHIVE}" DisplayVersion "${LCD_FILE_VERSION}"
  WriteRegStr HKLM "${UNINSTALL_SUBHIVE}" HelpLink "${LCD_URL}/faq_link.php"
  WriteRegStr HKLM "${UNINSTALL_SUBHIVE}" InstallLocation $INSTDIR
  WriteRegStr HKLM "${UNINSTALL_SUBHIVE}" Publisher "${LCD_COMPANY}"
  WriteRegStr HKLM "${UNINSTALL_SUBHIVE}" URLInfoAbout "${LCD_URL}"
  WriteRegStr HKLM "${UNINSTALL_SUBHIVE}" UninstallString "$INSTDIR\uninstall.exe"
  WriteRegDWORD HKLM "${UNINSTALL_SUBHIVE}" NoModify 1
  WriteRegDWORD HKLM "${UNINSTALL_SUBHIVE}" NoRepair 1
SectionEnd

;--------------------------------
;Descriptions

  ;Language strings
  LangString DESC_SgInstallation ${LANG_ENGLISH} "Options for where to install application software. Applicable if one or more other apps from The CrossWire Bible Society have been installed (or may be in the future)"
  LangString DESC_SecInstallApp ${LANG_ENGLISH} "Install application software (required)"
  LangString DESC_SecSwordProject ${LANG_ENGLISH} "If 'The SWORD Project' has already been installed (BibleCS), install LcdBible in the same directory (simplifies using the same resources without ending up with duplicate Bible texts)"
  LangString DESC_SecSwordPath ${LANG_ENGLISH} "Set environment variable for SWORD_PATH. Applicable if resources are in another directory besides subdirectories mods.d and modules 'under' the installation directory. Default: leave unchecked."
  LangString DESC_SgResources ${LANG_ENGLISH} "Choose from one or more resources (Bible text modules included in this download, commentaries/dictionaries/lexicons from The CrossWire Bible Society)"
  LangString DESC_SecIsvResource ${LANG_ENGLISH} "Install ISV (International Standard Version (New Testament). Included with this StarterKit to minimize the size of the download and avoid need to use the InstallManager."
  LangString DESC_SecKjvResource ${LANG_ENGLISH} "Install KJV (King James Version 1611/1769)"
  LangString DESC_SecWebResource ${LANG_ENGLISH} "Install WEB (World English Bible [Public Domain])"
  LangString DESC_SecBibleTexts ${LANG_ENGLISH} "Webpage from which to acquire additional Bible texts, commentaries, dictionaries, devotionals, and other modules (but preferred way to accomplish is using the InstallManager)"
  LangString DESC_SecReadme ${LANG_ENGLISH} "View Readme file (has information about using the InstallManager to get additional resources such as commentaries, other Bibles, devotionals, etc.)"
  LangString DESC_SecDesktopIcon ${LANG_ENGLISH} "Create icon on Desktop to simplify starting ${PROJECT_NAME} (double click on the icon to get the application going)"
  LangString DESC_SgRun ${LANG_ENGLISH} "Run Install Manager in order to acquire resources from The CrossWire Bible Society and then actually run the ${PROJECT_NAME} software"
  LangString DESC_SecInstallManager ${LANG_ENGLISH} "Run InstallManager to get, install, or uninstall resources from The CrossWire Bible Society"
  LangString DESC_SecRunApplication ${LANG_ENGLISH} "Run ${PROJECT_NAME} software. It will detect English language Bibles and make them available for use."
  LangString DESC_SgDocumentation ${LANG_ENGLISH} "Links to documentation-related resources (tutorials, change-log, web-pages, slideshow, etc.)"
  LangString DESC_SecDocMiniTutorial ${LANG_ENGLISH} "View one-page short tutorial ... basic functionality described"
  LangString DESC_SecDocFullTutorial ${LANG_ENGLISH} "View full tutorial (120+ steps oriented to less experienced users)"
  LangString DESC_SecDocChangeLog ${LANG_ENGLISH} "View Change-Log to see recent changes"
  LangString DESC_SecDocSlideshow ${LANG_ENGLISH} "View animated slideshow of very similar BerBible to gain familiarity with basic features of LcdBible (equiv for LceBible not yet prepared)"
  LangString DESC_SecDocCrosswireHome ${LANG_ENGLISH} "Visit homepage of The CrossWire Bible Society"
  LangString DESC_SecDocLcdBibleHome ${LANG_ENGLISH} "Visit homepage of the ${PROJECT_NAME} software"

  ;Assign language strings to sections
  !insertmacro MUI_FUNCTION_DESCRIPTION_BEGIN
    !insertmacro MUI_DESCRIPTION_TEXT ${SgInstallation} $(DESC_SgInstallation)
    !insertmacro MUI_DESCRIPTION_TEXT ${SecInstallApp} $(DESC_SecInstallApp)
    !insertmacro MUI_DESCRIPTION_TEXT ${SecSwordProject} $(DESC_SecSwordProject)
    !insertmacro MUI_DESCRIPTION_TEXT ${SecSwordPath} $(DESC_SecSwordPath)
    !insertmacro MUI_DESCRIPTION_TEXT ${SecIsvResource} $(DESC_SecIsvResource)
    !insertmacro MUI_DESCRIPTION_TEXT ${SgResources} $(DESC_SgResources)
    !insertmacro MUI_DESCRIPTION_TEXT ${SecKjvResource} $(DESC_SecKjvResource)
    !insertmacro MUI_DESCRIPTION_TEXT ${SecWebResource} $(DESC_SecWebResource)
    !insertmacro MUI_DESCRIPTION_TEXT ${SecBibleTexts} $(DESC_SecBibleTexts)
    !insertmacro MUI_DESCRIPTION_TEXT ${SecReadme} $(DESC_SecReadme)
    !insertmacro MUI_DESCRIPTION_TEXT ${SecDesktopIcon} $(DESC_SecDesktopIcon)
    !insertmacro MUI_DESCRIPTION_TEXT ${SgRun} $(DESC_SgRun)
    !insertmacro MUI_DESCRIPTION_TEXT ${SecInstallManager} $(DESC_SecInstallManager)
    !insertmacro MUI_DESCRIPTION_TEXT ${SecRunApplication} $(DESC_SecRunApplication)
    !insertmacro MUI_DESCRIPTION_TEXT ${SgDocumentation} $(DESC_SgDocumentation)
    !insertmacro MUI_DESCRIPTION_TEXT ${SecDocMiniTutorial} $(DESC_SecDocMiniTutorial)
    !insertmacro MUI_DESCRIPTION_TEXT ${SecDocFullTutorial} $(DESC_SecDocFullTutorial)
    !insertmacro MUI_DESCRIPTION_TEXT ${SecDocChangeLog} $(DESC_SecDocChangeLog)
    !insertmacro MUI_DESCRIPTION_TEXT ${SecDocSlideshow} $(DESC_SecDocSlideshow)
    !insertmacro MUI_DESCRIPTION_TEXT ${SecDocCrosswireHome} $(DESC_SecDocCrosswireHome)
    !insertmacro MUI_DESCRIPTION_TEXT ${SecDocLcdBibleHome} $(DESC_SecDocLcdBibleHome)
  !insertmacro MUI_FUNCTION_DESCRIPTION_END

;--------------------------------
;Uninstaller Section

Section "Uninstall"
  ;ADD YOUR OWN FILES HERE...

  Delete "$INSTDIR\Uninstall.exe"

  RMDir "$INSTDIR"

  DeleteRegKey /ifempty HKCU "Software\Modern UI Test"
SectionEnd

;--------------------------------
Function .onInit
!ifdef BCS_RELEASE_VERSION
  InitPluginsDir
  Push $R1
  File /oname=$PLUGINSDIR\spltmp.bmp ..\Sword.BMP
  advsplash::show 1000 1000 1000 -1 $PLUGINSDIR\spltmp
  Pop $R1
  Pop $R1
!endif

  SetRebootFlag false
  StrCpy $MyFlagSwordPathChanged "no"
  StrCpy $ViewFullTutorialFlag "no"
  ClearErrors
  ReadEnvStr $SwordPathFolder SWORD_PATH
;  StrCmp $SwordPathFolder "" OnInitSwordPathNotDefined OnInitSwordPathDefined

  ReadRegStr $TestMenuGroupExists HKCU "${LCD_REGKEY}" StartMenuGroup
  StrCmp $TestMenuGroupExists "" TmgeNo TmgeYes
  TmgeNo:
    StrCpy $StartMenuGroup "${PROJECT_FAMILY}_${PROJECT_NAME}"
    GoTo TmgeDone
  TmgeYes:
    StrCpy $StartMenuGroup $TestMenuGroupExists
  TmgeDone:
FunctionEnd

Function .onInstSuccess
FunctionEnd
